==> dojo-1.9.4.tgz: package/cldr/nls/ar/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"months-format-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"quarters-standAlone-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-weekday": "اليوم",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E، d/‏M/‏y",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-MMMEd": "E، d MMM",
	"eraNarrow": [
		"ق.م",
		"م"
	],
	"dateFormatItem-yMM": "MM‏/y",
	"days-format-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormat-long": "d MMMM، y",
	"months-format-wide": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "م",
	"dateFormat-full": "EEEE، d MMMM، y",
	"dateFormatItem-Md": "d/‏M",
	"dateFormatItem-yMd": "d‏/M‏/y",
	"field-era": "العصر",
	"dateFormatItem-yM": "M‏/y",
	"months-standAlone-wide": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "السنة",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "الساعات",
	"dateFormatItem-MMdd": "dd‏/MM",
	"months-format-abbr": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "اليوم",
	"field-day-relative+1": "غدًا",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"field-day-relative+2": "بعد الغد",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"quarters-format-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"quarters-standAlone-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "h:mm:ss a",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"eraAbbr": [
		"ق.م",
		"م"
	],
	"field-minute": "الدقائق",
	"field-dayperiod": "ص/م",
	"days-standAlone-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-day-relative+-1": "أمس",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "أول أمس",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E، d/M",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-day": "يوم",
	"days-format-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-zone": "التوقيت",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"field-year-relative+-1": "السنة الماضية",
	"field-month-relative+-1": "الشهر الماضي",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yMMMd": "d MMM، y",
	"eraNames": [
		"قبل الميلاد",
		"ميلادي"
	],
	"days-format-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"field-month": "الشهر",
	"days-standAlone-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"dateFormatItem-MMM": "LLL",
	"dayPeriods-format-wide-am": "ص",
	"dateFormatItem-MMMMEd": "E، d MMMM",
	"dateFormat-short": "d‏/M‏/y",
	"field-second": "الثواني",
	"dateFormatItem-yMMMEd": "E، d MMM، y",
	"field-month-relative+0": "هذا الشهر",
	"field-month-relative+1": "الشهر التالي",
	"dateFormatItem-Ed": "E، d",
	"field-week": "الأسبوع",
	"dateFormat-medium": "dd‏/MM‏/y",
	"field-year-relative+0": "هذه السنة",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-year-relative+1": "السنة التالية",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/ar/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"months-format-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"field-second-relative+0": "الآن",
	"quarters-standAlone-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-weekday": "اليوم",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E، d/‏M/‏y",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء التالي",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-MMMEd": "E، d MMM",
	"eraNarrow": [
		"ق.م",
		"م"
	],
	"dateFormatItem-yMM": "MM‏/y",
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"days-format-short": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormat-long": "d MMMM، y",
	"field-fri-relative+-1": "الجمعة الماضية",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"months-format-wide": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "م",
	"dateFormat-full": "EEEE، d MMMM، y",
	"field-thu-relative+-1": "الخميس الماضي",
	"dateFormatItem-Md": "d/‏M",
	"dateFormatItem-yMd": "d‏/M‏/y",
	"field-era": "العصر",
	"dateFormatItem-yM": "M‏/y",
	"months-standAlone-wide": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"timeFormat-short": "h:mm a",
	"quarters-format-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "h:mm:ss a z",
	"field-year": "السنة",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "الساعات",
	"dateFormatItem-MMdd": "dd‏/MM",
	"months-format-abbr": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"field-sat-relative+0": "السبت الحالي",
	"field-sat-relative+1": "السبت التالي",
	"timeFormat-full": "h:mm:ss a zzzz",
	"field-day-relative+0": "اليوم",
	"field-thu-relative+0": "الخميس الحالي",
	"field-day-relative+1": "غدًا",
	"field-thu-relative+1": "الخميس التالي",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"field-day-relative+2": "بعد الغد",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"يناير",
		"فبراير",
		"مارس",
		"أبريل",
		"مايو",
		"يونيو",
		"يوليو",
		"أغسطس",
		"سبتمبر",
		"أكتوبر",
		"نوفمبر",
		"ديسمبر"
	],
	"quarters-format-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"quarters-standAlone-wide": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "h:mm:ss a",
	"field-sun-relative+0": "الأحد الحالي",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "الأحد التالي",
	"quarters-standAlone-abbr": [
		"الربع الأول",
		"الربع الثاني",
		"الربع الثالث",
		"الربع الرابع"
	],
	"eraAbbr": [
		"ق.م",
		"م"
	],
	"field-minute": "الدقائق",
	"field-dayperiod": "ص/م",
	"days-standAlone-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"١",
		"٢",
		"٣",
		"٤"
	],
	"field-day-relative+-1": "أمس",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "أول أمس",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E، d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "الجمعة الحالية",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "الجمعة التالية",
	"field-day": "يوم",
	"days-format-wide": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"field-zone": "التوقيت",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"ي",
		"ف",
		"م",
		"أ",
		"و",
		"ن",
		"ل",
		"غ",
		"س",
		"ك",
		"ب",
		"د"
	],
	"field-year-relative+-1": "السنة الماضية",
	"field-month-relative+-1": "الشهر الماضي",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"الأحد",
		"الاثنين",
		"الثلاثاء",
		"الأربعاء",
		"الخميس",
		"الجمعة",
		"السبت"
	],
	"dateFormatItem-yMMMd": "d MMM، y",
	"eraNames": [
		"قبل الميلاد",
		"ميلادي"
	],
	"days-format-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"days-standAlone-narrow": [
		"ح",
		"ن",
		"ث",
		"ر",
		"خ",
		"ج",
		"س"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "الشهر",
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-tue-relative+1": "الثلاثاء التالي",
	"dayPeriods-format-wide-am": "ص",
	"dateFormatItem-MMMMEd": "E، d MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "الاثنين الحالي",
	"field-mon-relative+1": "الاثنين التالي",
	"dateFormat-short": "d‏/M‏/y",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-second": "الثواني",
	"field-sat-relative+-1": "السبت الماضي",
	"dateFormatItem-yMMMEd": "E، d MMM، y",
	"field-sun-relative+-1": "الأحد الماضي",
	"field-month-relative+0": "هذا الشهر",
	"field-month-relative+1": "الشهر التالي",
	"dateFormatItem-Ed": "E، d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "الأسبوع",
	"dateFormat-medium": "dd‏/MM‏/y",
	"field-year-relative+0": "السنة الحالية",
	"field-week-relative+-1": "الأسبوع الماضي",
	"field-year-relative+1": "السنة التالية",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "الاثنين الماضي",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي"
}
//end v1.x content
);
